==> nextcloud-31.0.2-2-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/photos/l10n/gl.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Ligazón pública",
    "Photos" : "Fotos",
    "On This Day" : "Neste día",
    "Your memories under your control" : "As súas lembranzas baixo o seu control",
    "All media" : "Todos os medios",
    "Videos" : "Vídeos",
    "Albums" : "Álbums",
    "Collaborative albums" : "Álbums colaborativos",
    "People" : "Persoas",
    "Folders" : "Cartafoles",
    "Favorites" : "Favoritos",
    "On this day" : "Neste día",
    "Shared with you" : "Compartido con Vde.",
    "Tags" : "Etiquetas",
    "Places" : "Lugares",
    "Map" : "Mapa",
    "Photos settings" : "Axustes de Fotos",
    "Mark selection as favorite" : "Marcar a selección como favorita",
    "Add selection to favorites" : "Engadir a selección a favoritos",
    "Remove selection from favorites" : "Retirar a selección dos favoritos",
    "Name of the album" : "Nome do álbum",
    "Location of the album" : "Localización do álbum",
    "Back" : "Atrás",
    "Add collaborators" : "Engadir colaboradores",
    "Save" : "Gardar",
    "Create album" : "Crear álbum.",
    "Add to Album" : "Engadir ao álbum",
    "Add selection to album {albumName}" : "Engadir a selección ao álbum {albumName}",
    "Shared by" : "Compartido por",
    "Create a new album." : "Crear un novo álbum.",
    "Create new album" : "Crear novo álbum",
    "New album" : "Novo álbum",
    "_%n item_::_%n photos and videos_" : ["%n elemento","%n fotos e vídeos"],
    "Failed to fetch collaborators list." : "Produciuse un fallo ao recuperar a lista de colaboradores.",
    "Failed to update album." : "Produciuse un fallo ao actualizar o álbum.",
    "Add people or groups who can edit your album" : "Engadir persoas ou grupos que poidan editar o seu álbum",
    "Search people or groups" : "Buscar persoas ou grupos",
    "No recommendations. Start typing." : "Non hai recomendacións. Comece a escribir.",
    "Group" : "Grupo",
    "Remove {collaboratorLabel} from the collaborators list" : "Retirar a {collaboratorLabel} da lista de colaboradores",
    "Copy the public link" : "Copiar a ligazón pública",
    "Public link copied!" : "Copiouse a ligazón pública!",
    "Copy public link" : "Copiar a ligazón pública",
    "Delete the public link" : "Eliminar a ligazón pública",
    "Create public link share" : "Crear unha ligazón pública compartida",
    "Share via public link" : "Compartir mediante ligazón pública",
    "This collection does not exist" : "Esta colección non existe",
    "An error occurred" : "Produciuse un erro",
    "No picture for this day" : "Non hai imaxes para este día",
    "Picture taken on this day will show up here." : "A imaxe tomada este día aparecerá aquí.",
    "More photos from this day" : "Máis fotos deste día",
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n foto sen asignar","%n fotos sen asignar"],
    "Favorite" : "Favorito",
    "Favorite image, open the full size \"{name}\" image" : "Imaxe favorita, abrir a imaxe «{name}». a tamaño completo",
    "Open the full size \"{name}\" image" : "Abrir a imaxe «{name}» a tamaño real",
    "Select image {imageName}" : "Seleccionar a imaxe {imageName}",
    "Open the \"{name}\" folder" : "Abrir o cartafol «{name}»",
    "Back to {folder}" : "Volver a {folder}",
    "Go back" : "Volver",
    "Share this folder" : "Compartir este cartafol",
    "Dates" : "Datas",
    "Jump to specific date in list" : "Ir á data específica da lista",
    "Jump to {date}" : "Ir a {data}",
    "Add to {destination}" : "Engadir a {destination}",
    "The destination folder is owned by {owner}" : "O cartafol de destino é propiedade de {owner}",
    "There are no photos or videos yet!" : "Aínda non hai fotos nin vídeos!",
    "_{years} year ago_::_{years} years ago_" : ["Hai {years} ano","Hai {years} anos"],
    "Enable squared photos view" : "Activar a vista de fotos cadradas",
    "Delete source directory" : "Eliminar o directorio de orixe",
    "Pick folder" : "Escoller cartafol",
    "Select a source folder for your media" : "Seleccione un cartafol de orixe para os seus ficheiros multimedia",
    "All folders" : "Todos os cartafoles",
    "Add a Photos source for the timelines" : "Engada unha orixe de Fotos para as cronoloxías",
    "Add folder" : "Engadir cartafol",
    "Select the default upload location for your media" : "Seleccione a localización de envío predeterminada para os seus ficheiros multimedia",
    "Home" : "Inicio",
    "Choose default Photos upload and Albums location" : "Escolla o envío predeterminado en Fotos e a localización en Álbums",
    "Choose a different folder" : "Escolla un cartafol diferente",
    "View" : "Ver",
    "Media folders" : "Cartafol de ficheiros multimedia",
    "Choose the folders from where photos and videos are shown." : "Escolla os cartafoles nos que se amosarán as fotos e os vídeos.",
    "Upload folder" : "Enviar cartafol",
    "Choose the folder where photos and albums are uploaded to." : "Escolla o cartafol ao que se enviarán as fotos e os álbums.",
    "_%n photo_::_%n photos_" : ["%n foto","%n fotos"],
    "Unselect all" : "Deseleccionar todo",
    "Add photos to this album" : "Engadir fotos a este álbum",
    "Manage collaborators for this album" : "Xestionar os colaboradores deste álbum",
    "Open actions menu" : "Abrir o menú de accións",
    "Edit album details" : "Editar os detalles do álbum",
    "Download all files in album" : "Descargar todos os ficheiros do álbum",
    "Delete album" : "Eliminar álbum",
    "Download selected files" : "Descargar os ficheiros seleccionados",
    "Remove selection from album" : "Retirar a selección do álbum",
    "This album does not have any photos or videos yet!" : "Este álbum aínda non ten fotos nin vídeos!",
    "Add photos to {albumName}" : "Engadir fotos a {albumName}",
    "Manage collaborators" : "Xestionar colaboradores",
    "Save collaborators for this album." : "Gardar os colaboradores para este álbum.",
    "Cover photo for album {albumName}" : "Foto de portada do álbum {albumName}",
    "There is no album yet!" : "Aínda non hai ningún álbum!",
    "This person could not be found" : "Non foi posíbel atopar esta persoa",
    "Rename person" : "Cambiar o nome da persoa",
    "Merge with different person" : "Combinar cunha persoa diferente",
    "Download selected photos" : "Descargar as fotos seleccionadas",
    "Remove from favorites" : "Retirar dos favoritos",
    "Remove person" : "Retirar persoa",
    "Name of this person" : "Nome desta persoa",
    "Save." : "Gardar.",
    "Merge person" : "Combinar persoa",
    "Move to different person" : "Mover cara a outra persoa",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Mover a foto cara a outra persoa","Mover as foto cara a outra persoa"],
    "_Remove photo from person_::_Remove photos from person_" : ["Retirar foto desta persoa","Retirar fotos desta persoa"],
    "This might take some time depending on the size of your photo library." : "Isto pode levar algún tempo dependendo do tamaño da súa fototeca.",
    "Recognized people will show up here" : "Aquí aparecerán as persoas recoñecidas",
    "This folder does not exist" : "Este cartafol non existe",
    "Loading folders …" : "Cargando cartafoles…",
    "No photos in here" : "Aquí non hai fotos",
    "Taken on {date} at {time}" : "Tirada o {date} ás {time}",
    "This place does not have any photos or videos yet!" : "Este lugar aínda non ten fotos nin vídeos!",
    "Add photos to this place" : "Engadir fotos a este lugar",
    "Cover photo for place {placeName}" : "Foto de portada do lugar {placeName}",
    "There is no place yet!" : "Aínda non hai lugar!",
    "Cover photo for shared album {albumName}." : "Foto de portada do álbum compartido {albumName}.",
    "Back to tags overview" : "Volver á vista xeral das etiquetas",
    "No photos with this tag yet" : "Aínda non hai fotos con esta etiqueta",
    "No tags yet" : "Non hai ren etiquetado",
    "Photos with tags will show up here" : "As fotos etiquetadas aparecerán aquí",
    "Popular tags" : "Etiquetas populares",
    "All tags" : "Todas as etiquetas",
    "One of the source folders does not exist" : "Un dos cartafoles de orixe non existe",
    "Add to album" : "Engadir ao álbum",
    "Delete selection" : "Eliminar a selección",
    "No photos or videos in here" : "Aquí non hai fotos nin vídeos",
    "Unassigned faces" : "Facianas sen asignar",
    "_%n photos_::_%n photos_" : ["%n fotos","%n fotos"],
    "Failed to fetch collection." : "Produciuse un fallo ao recuperar a colección.",
    "Failed to fetch collections list." : "Produciuse un fallo ao recuperar a lista de coleccións.",
    "Failed to fetch faces list." : "Produciuse un fallo ao recuperar a lista de facianas.",
    "All your media" : "Todos os seus medios",
    "Album {title}" : "Álbum {title}",
    "Shared Albums" : "Álbums compartidos",
    "Shared album {title}" : "Álbum compartido {title}",
    "Public album {title}" : "Álbum público {title}",
    "Tagged photos" : "Fotos etiquetadas",
    "Tagged photo {title}" : "Foto etiquetada {title}",
    "{title}'s face" : "A faciana de {title}",
    "{startDate} to {endDate}" : "{startDate} ata o {endDate}",
    "Details" : "Detalles",
    "Failed to rename {oldName} to {faceName}." : "Non foi posíbel cambiar o nome de {oldName} a {faceName}.",
    "Failed to delete {faceName}." : "Produciuse un fallo ao eliminar {faceName}.",
    "Failed to delete {fileId}." : "Produciuse un fallo ao eliminar {fileId}.",
    "Failed to delete {fileName}." : "Produciuse un fallo ao eliminar {fileName}.",
    "Failed to set favorite state for {fileId}." : "Non foi posíbel definir o estado de favorito para {fileId}.",
    "Failed to set favorite state for {fileName}." : "Non foi posíbel definir o estado de favorito para {fileName}.",
    "Could not load photos folder" : "Non foi posíbel cargar o cartafol de fotos",
    "One of the source folders does not exists" : "Un dos cartafoles de orixe non existe",
    "Add" : "Engadir"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-32.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/photos/l10n/gl.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Ligazón pública",
    "Photos" : "Fotos",
    "On This Day" : "Neste día",
    "Your memories under your control" : "As súas lembranzas baixo o seu control",
    "All media" : "Todos os medios",
    "Videos" : "Vídeos",
    "Albums" : "Álbums",
    "Collaborative albums" : "Álbums colaborativos",
    "People" : "Persoas",
    "Folders" : "Cartafoles",
    "Favorites" : "Favoritos",
    "On this day" : "Neste día",
    "Shared with you" : "Compartido con Vde.",
    "Tags" : "Etiquetas",
    "Places" : "Lugares",
    "Map" : "Mapa",
    "Photos settings" : "Axustes de Fotos",
    "Mark selection as favorite" : "Marcar a selección como favorita",
    "Add selection to favorites" : "Engadir a selección a favoritos",
    "Remove selection from favorites" : "Retirar a selección dos favoritos",
    "This name is already in use." : "Este nome xa está a ser usado",
    "\"{char}\" is not allowed inside a filename." : "«{char}» non está permitido nun nome de ficheiro.",
    "Invalid filename." : "Nome de ficheiro incorrecto.",
    "Name of the album" : "Nome do álbum",
    "Location of the album" : "Localización do álbum",
    "Back" : "Atrás",
    "Add collaborators" : "Engadir colaboradores",
    "Save" : "Gardar",
    "Create album" : "Crear álbum.",
    "Add to Album" : "Engadir ao álbum",
    "Add selection to album {albumName}" : "Engadir a selección ao álbum {albumName}",
    "Shared by" : "Compartido por",
    "Create a new album." : "Crear un novo álbum.",
    "Create new album" : "Crear novo álbum",
    "New album" : "Novo álbum",
    "_%n item_::_%n photos and videos_" : ["%n elemento","%n fotos e vídeos"],
    "Failed to fetch collaborators list." : "Produciuse un fallo ao recuperar a lista de colaboradores.",
    "Failed to update album." : "Produciuse un fallo ao actualizar o álbum.",
    "Add people or groups who can edit your album" : "Engadir persoas ou grupos que poidan editar o seu álbum",
    "Search people or groups" : "Buscar persoas ou grupos",
    "No recommendations. Start typing." : "Non hai recomendacións. Comece a escribir.",
    "Copy the public link" : "Copiar a ligazón pública",
    "Public link copied!" : "Copiouse a ligazón pública!",
    "Copy public link" : "Copiar a ligazón pública",
    "Delete the public link" : "Eliminar a ligazón pública",
    "Create public link share" : "Crear unha ligazón pública para compartir",
    "Share via public link" : "Compartir mediante ligazón pública",
    "This collection does not exist" : "Esta colección non existe",
    "An error occurred" : "Produciuse un erro",
    "No picture for this day" : "Non hai imaxes para este día",
    "Picture taken on this day will show up here." : "A imaxe tomada este día aparecerá aquí.",
    "More photos from this day" : "Máis fotos deste día",
    "_%n photos_::_%n photos_" : ["%n fotos","%n fotos"],
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n foto sen asignar","%n fotos sen asignar"],
    "Favorite" : "Favorito",
    "Favorite image, open the full size \"{name}\" image" : "Imaxe favorita, abrir a imaxe «{name}». a tamaño completo",
    "Open the full size \"{name}\" image" : "Abrir a imaxe «{name}» a tamaño real",
    "Select image {imageName}" : "Seleccionar a imaxe {imageName}",
    "Open the \"{name}\" folder" : "Abrir o cartafol «{name}»",
    "Go back" : "Volver",
    "Select a custom date range" : "Seleccionar un intervalo de datas personalizado",
    "Select a date range" : "Seleccionar un intervalo de datas",
    "Date range" : "Intervalo de datas",
    "Select filters" : "Seleccionar filtros",
    "Dates" : "Datas",
    "Jump to specific date in list" : "Ir á data específica da lista",
    "Jump to {date}" : "Ir a {data}",
    "Add to {destination}" : "Engadir a {destination}",
    "The destination folder is owned by {owner}" : "O cartafol de destino é propiedade de {owner}",
    "There are no photos or videos yet!" : "Aínda non hai fotos nin vídeos!",
    "_{years} year ago_::_{years} years ago_" : ["Hai {years} ano","Hai {years} anos"],
    "Squared photos view" : "Vista das fotos en cadrado",
    "Delete source directory" : "Eliminar o directorio de orixe",
    "Pick folder" : "Escoller cartafol",
    "Select a source folder for your media" : "Seleccione un cartafol de orixe para os seus ficheiros multimedia",
    "Media folders" : "Cartafol de ficheiros multimedia",
    "Choose the folders from where photos and videos are shown." : "Escolla os cartafoles nos que se amosarán as fotos e os vídeos.",
    "All folders" : "Todos os cartafoles",
    "Add a Photos source for the timelines" : "Engada unha orixe de Fotos para as cronoloxías",
    "Add folder" : "Engadir cartafol",
    "Home" : "Inicio",
    "Select the default upload location for your media" : "Seleccione a localización de envío predeterminada para os seus ficheiros multimedia",
    "Upload folder" : "Enviar cartafol",
    "General" : "Xeral",
    "_%n photo_::_%n photos_" : ["%n foto","%n fotos"],
    "Unselect all" : "Deseleccionar todo",
    "Add photos to this album" : "Engadir fotos a este álbum",
    "Manage collaborators for this album" : "Xestionar os colaboradores deste álbum",
    "Open actions menu" : "Abrir o menú de accións",
    "Edit album details" : "Editar os detalles do álbum",
    "Download all files in album" : "Descargar todos os ficheiros do álbum",
    "Delete album" : "Eliminar álbum",
    "Download selected files" : "Descargar os ficheiros seleccionados",
    "Remove selection from album" : "Retirar a selección do álbum",
    "This album does not have any photos or videos yet!" : "Este álbum aínda non ten fotos nin vídeos!",
    "Add photos to {albumName}" : "Engadir fotos a {albumName}",
    "Manage collaborators" : "Xestionar colaboradores",
    "Save collaborators for this album." : "Gardar os colaboradores para este álbum.",
    "Cover photo for album {albumName}" : "Foto de portada do álbum {albumName}",
    "There is no album yet!" : "Aínda non hai ningún álbum!",
    "This person could not be found" : "Non foi posíbel atopar esta persoa",
    "Rename person" : "Cambiar o nome da persoa",
    "Merge with different person" : "Combinar cunha persoa diferente",
    "Download selected photos" : "Descargar as fotos seleccionadas",
    "Remove from favorites" : "Retirar dos favoritos",
    "Remove person" : "Retirar persoa",
    "Name of this person" : "Nome desta persoa",
    "Save." : "Gardar.",
    "Merge person" : "Combinar persoa",
    "Move to different person" : "Mover cara a outra persoa",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Mover a foto cara a outra persoa","Mover as foto cara a outra persoa"],
    "_Remove photo from person_::_Remove photos from person_" : ["Retirar foto desta persoa","Retirar fotos desta persoa"],
    "This might take some time depending on the size of your photo library." : "Isto pode levar algún tempo dependendo do tamaño da súa fototeca.",
    "Recognized people will show up here" : "Aquí aparecerán as persoas recoñecidas",
    "This folder does not exist" : "Este cartafol non existe",
    "Loading folders…" : "Cargando cartafoles…",
    "No photos in here" : "Aquí non hai fotos",
    "Taken on {date} at {time}" : "Tirada o {date} ás {time}",
    "This place does not have any photos or videos yet!" : "Este lugar aínda non ten fotos nin vídeos!",
    "Add photos to this place" : "Engadir fotos a este lugar",
    "Cover photo for place {placeName}" : "Foto de portada do lugar {placeName}",
    "There is no place yet!" : "Aínda non hai lugar!",
    "Cover photo for shared album {albumName}" : "Foto de portada do álbum compartido {albumName}",
    "Back to tags overview" : "Volver á vista xeral das etiquetas",
    "No photos with this tag yet" : "Aínda non hai fotos con esta etiqueta",
    "No tags yet" : "Non hai ren etiquetado",
    "Photos with tags will show up here" : "As fotos etiquetadas aparecerán aquí",
    "Popular tags" : "Etiquetas populares",
    "All tags" : "Todas as etiquetas",
    "Create new album from filters" : "Crear un novo álbum a partir de filtros",
    "One of the source folders does not exist" : "Un dos cartafoles de orixe non existe",
    "Add to album" : "Engadir ao álbum",
    "Delete selection" : "Eliminar a selección",
    "No photos or videos in here" : "Aquí non hai fotos nin vídeos",
    "Unassigned faces" : "Facianas sen asignar",
    "Failed to fetch collection." : "Produciuse un fallo ao recuperar a colección.",
    "Failed to fetch collections list." : "Produciuse un fallo ao recuperar a lista de coleccións.",
    "Failed to fetch faces list." : "Produciuse un fallo ao recuperar a lista de facianas.",
    "Error fetching files" : "Produciuse un erro ao recuperar ficheiros",
    "All your media" : "Todos os seus medios",
    "Album {title}" : "Álbum {title}",
    "Shared Albums" : "Álbums compartidos",
    "Shared album {title}" : "Álbum compartido {title}",
    "Public album {title}" : "Álbum público {title}",
    "Tagged photos" : "Fotos etiquetadas",
    "Tagged photo {title}" : "Foto etiquetada {title}",
    "{title}'s face" : "A faciana de {title}",
    "Last week" : "Última semana",
    "Last Month" : "Último mes",
    "Custom…" : "Personalizado…",
    "{startDate} to {endDate}" : "{startDate} ata o {endDate}",
    "Details" : "Detalles",
    "Failed to add {fileBaseName} to collection {collectionFileName}" : "Produciuse un fallo ao engadir {fileBaseName} á colección {collectionFileName}",
    "Failed to delete {fileBaseName}" : "Produciuse un fallo ao eliminar {fileBaseName}",
    "Failed to create {collectionFileName}" : "Produciuse un fallo ao crear {collectionFileName}",
    "Failed to rename {currentCollectionFileName} to {newCollectionFileName}" : "Produciuse un fallo ao cambiar o nome de {currentCollectionFileName} a {newCollectionFileName}",
    "Failed to update properties of {collectionFileName} with {properties}" : "Produciuse un fallo ao actualizar as propiedades de {collectionFileName} con {properties}.",
    "Delete collection" : "Eliminar a colección",
    "Leave shared album" : "Abandonar o álbum compartido",
    "Are you sure you want to delete {collectionName}? This action cannot be undone." : "Confirma que quere eliminar {collectionName}? Esta acción non é posíbel desfacela.",
    "Failed to delete {collectionFileName}" : "Produciuse un fallo ao eliminar {collectionFileName}",
    "Cancel" : "Cancelar",
    "Confirm" : "Confirmar",
    "Failed to move {fileBaseName} to person {faceName}" : "Produciuse un fallo ao mover {fileBaseName} para a persoa {faceName}",
    "Failed to remove {fileBaseName}" : "Produciuse un fallo ao retirar {fileBaseName}",
    "Failed to rename {oldName} to {faceName}" : "Produciuse un fallo ao cambiar o nome de {oldName} a {faceName}",
    "Failed to delete {faceName}" : "Produciuse un fallo ao eliminar {faceName}",
    "Failed to delete {fileId}" : "Produciuse un fallo ao eliminar {fileId}",
    "Failed to delete {fileName}" : "Produciuse un fallo ao eliminar {fileName}",
    "Failed to set favorite state for {fileId}" : "Produciuse un fallo ao definir o estado de favorito para {fileId}",
    "Failed to set favorite state for {fileName}" : "Produciuse un fallo ao definir o estado de favorito para {fileName}",
    "Could not load photos folder" : "Non foi posíbel cargar o cartafol de fotos",
    "Group" : "Grupo",
    "Remove {collaboratorLabel} from the collaborators list" : "Retirar a {collaboratorLabel} da lista de colaboradores",
    "Back to {folder}" : "Volver a {folder}",
    "Share this folder" : "Compartir este cartafol",
    "Enable squared photos view" : "Activar a vista das fotos en cadrado",
    "Choose default Photos upload and Albums location" : "Escolla o envío predeterminado en Fotos e a localización en Álbums",
    "Choose a different folder" : "Escolla un cartafol diferente",
    "View" : "Ver",
    "Choose the folder where photos and albums are uploaded to." : "Escolla o cartafol ao que se enviarán as fotos e os álbums.",
    "Loading folders …" : "Cargando cartafoles…",
    "Add" : "Engadir"
},
"nplurals=2; plural=(n != 1);");
